<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [assert.dom()][1]
-   [DOMAssertions][2]
    -   [exists][3]
        -   [Parameters][4]
        -   [Examples][5]
    -   [doesNotExist][6]
        -   [Parameters][7]
        -   [Examples][8]
    -   [isChecked][9]
        -   [Parameters][10]
        -   [Examples][11]
    -   [isNotChecked][12]
        -   [Parameters][13]
        -   [Examples][14]
    -   [isFocused][15]
        -   [Parameters][16]
        -   [Examples][17]
    -   [isNotFocused][18]
        -   [Parameters][19]
        -   [Examples][20]
    -   [isRequired][21]
        -   [Parameters][22]
        -   [Examples][23]
    -   [isNotRequired][24]
        -   [Parameters][25]
        -   [Examples][26]
    -   [isVisible][27]
        -   [Parameters][28]
        -   [Examples][29]
    -   [isNotVisible][30]
        -   [Parameters][31]
        -   [Examples][32]
    -   [hasAttribute][33]
        -   [Parameters][34]
        -   [Examples][35]
    -   [doesNotHaveAttribute][36]
        -   [Parameters][37]
        -   [Examples][38]
    -   [isDisabled][39]
        -   [Parameters][40]
        -   [Examples][41]
    -   [isNotDisabled][42]
        -   [Parameters][43]
        -   [Examples][44]
    -   [hasClass][45]
        -   [Parameters][46]
        -   [Examples][47]
    -   [doesNotHaveClass][48]
        -   [Parameters][49]
        -   [Examples][50]
    -   [hasText][51]
        -   [Parameters][52]
        -   [Examples][53]
    -   [hasAnyText][54]
        -   [Parameters][55]
        -   [Examples][56]
    -   [includesText][57]
        -   [Parameters][58]
        -   [Examples][59]
    -   [doesNotIncludeText][60]
        -   [Parameters][61]
        -   [Examples][62]
    -   [hasValue][63]
        -   [Parameters][64]
        -   [Examples][65]
    -   [hasAnyValue][66]
        -   [Parameters][67]
        -   [Examples][68]
    -   [hasNoValue][69]
        -   [Parameters][70]
        -   [Examples][71]
    -   [matchesSelector][72]
        -   [Parameters][73]
        -   [Examples][74]
    -   [doesNotMatchSelector][75]
        -   [Parameters][76]
        -   [Examples][77]
-   [hasStyle][78]
    -   [Parameters][79]
    -   [Examples][80]
-   [hasPseudoElementStyle][81]
    -   [Parameters][82]
    -   [Examples][83]

## assert.dom()

Once installed the DOM element assertions are available at `assert.dom(...).*`:

**Parameters**

-   `target` **([string][84] \| [HTMLElement][85])** A CSS selector that can be used to find elements using [`querySelector()`][86], or an [HTMLElement][] (Not all assertions support both target types.) (optional, default `rootElement` or `document`)
-   `rootElement` **[HTMLElement][85]?** The root element of the DOM in which to search for the `target` (optional, default `document`)

**Examples**

```javascript
test('the title exists', function(assert) {
  assert.dom('#title').exists();
});
```


## DOMAssertions

### exists

-   **See: [#doesNotExist][87]**

Assert an [HTMLElement][88] (or multiple) matching the `selector` exists.

#### Parameters

-   `options` **[object][89]?** 
    -   `options.count` **[number][90]?** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('#title').exists();
assert.dom('.choice').exists({ count: 4 });
```

### doesNotExist

-   **See: [#exists][3]**

Assert an [HTMLElement][88] matching the `selector` does not exists.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('.should-not-exist').doesNotExist();
```

### isChecked

-   **See: [#isNotChecked][92]**

Assert that the [HTMLElement][88] or an [HTMLElement][88] matching the
`selector` is currently checked.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input.active').isChecked();
```

### isNotChecked

-   **See: [#isChecked][93]**

Assert that the [HTMLElement][88] or an [HTMLElement][88] matching the
`selector` is currently unchecked.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input.active').isNotChecked();
```

### isFocused

-   **See: [#isNotFocused][94]**

Assert that the [HTMLElement][88] or an [HTMLElement][88] matching the
`selector` is currently focused.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input.email').isFocused();
```

### isNotFocused

-   **See: [#isFocused][95]**

Assert that the [HTMLElement][88] or an [HTMLElement][88] matching the
`selector` is not currently focused.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input[type="password"]').isNotFocused();
```

### isRequired

-   **See: [#isNotRequired][96]**

Assert that the [HTMLElement][88] or an [HTMLElement][88] matching the
`selector` is currently required.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input[type="text"]').isRequired();
```

### isNotRequired

-   **See: [#isRequired][97]**

Assert that the [HTMLElement][88] or an [HTMLElement][88] matching the
`selector` is currently not required.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input[type="text"]').isNotRequired();
```

### isVisible

-   **See: [#isNotVisible][98]**

Assert that the [HTMLElement][88] or an [HTMLElement][88] matching the
`selector` exists and is visible.

Visibility is determined by asserting that:

-   the element's offsetWidth and offsetHeight are non-zero
-   any of the element's DOMRect objects have a non-zero size

Additionally, visibility in this case means that the element is visible on the page,
but not necessarily in the viewport.

#### Parameters

-   `options` **[object][89]?** 
    -   `options.count` **[number][90]?** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('#title').isVisible();
assert.dom('.choice').isVisible({ count: 4 });
```

### isNotVisible

-   **See: [#isVisible][99]**

Assert that the [HTMLElement][88] or an [HTMLElement][88] matching the
`selector` does not exist or is not visible on the page.

Visibility is determined by asserting that:

-   the element's offsetWidth or offsetHeight are zero
-   all of the element's DOMRect objects have a size of zero

Additionally, visibility in this case means that the element is visible on the page,
but not necessarily in the viewport.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('.foo').isNotVisible();
```

### hasAttribute

-   **See: [#doesNotHaveAttribute][100]**

Assert that the [HTMLElement][88] has an attribute with the provided `name`
and optionally checks if the attribute `value` matches the provided text
or regular expression.

#### Parameters

-   `name` **[string][91]** 
-   `value` **([string][91] \| [RegExp][101] \| [object][89]?)** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input.password-input').hasAttribute('type', 'password');
```

### doesNotHaveAttribute

-   **See: [#hasAttribute][102]**

Assert that the [HTMLElement][88] has no attribute with the provided `name`.

**Aliases:** `hasNoAttribute`, `lacksAttribute`

#### Parameters

-   `name` **[string][91]** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input.username').hasNoAttribute('disabled');
```

### isDisabled

-   **See: [#isNotDisabled][103]**

Assert that the [HTMLElement][88] or an [HTMLElement][88] matching the
`selector` is disabled.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('.foo').isDisabled();
```

### isNotDisabled

-   **See: [#isDisabled][104]**

Assert that the [HTMLElement][88] or an [HTMLElement][88] matching the
`selector` is not disabled.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('.foo').isNotDisabled();
```

### hasClass

-   **See: [#doesNotHaveClass][105]**

Assert that the [HTMLElement][88] has the `expected` CSS class using
[`classList`][106].

#### Parameters

-   `expected` **[string][91]** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input[type="password"]').hasClass('secret-password-input');
```

### doesNotHaveClass

-   **See: [#hasClass][107]**

Assert that the [HTMLElement][88] does not have the `expected` CSS class using
[`classList`][106].

**Aliases:** `hasNoClass`, `lacksClass`

#### Parameters

-   `expected` **[string][91]** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input[type="password"]').doesNotHaveClass('username-input');
```

### hasText

-   **See: [#includesText][108]**

Assert that the text of the [HTMLElement][88] or an [HTMLElement][88]
matching the `selector` matches the `expected` text, using the
[`textContent`][109]
attribute and stripping/collapsing whitespace.

`expected` can also be a regular expression.

> Note: This assertion will collapse whitespace if the type you pass in is a string.
> If you are testing specifically for whitespace integrity, pass your expected text
> in as a RegEx pattern.

**Aliases:** `matchesText`

#### Parameters

-   `expected` **([string][91] \| [RegExp][101])** 
-   `message` **[string][91]?** 

#### Examples

```javascript
// <h2 id="title">
//   Welcome to <b>QUnit</b>
// </h2>

assert.dom('#title').hasText('Welcome to QUnit');
```

```javascript
assert.dom('.foo').hasText(/[12]\d{3}/);
```

### hasAnyText

-   **See: [#hasText][110]**

Assert that the `textContent` property of an [HTMLElement][88] is not empty.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('button.share').hasAnyText();
```

### includesText

-   **See: [#hasText][110]**

Assert that the text of the [HTMLElement][88] or an [HTMLElement][88]
matching the `selector` contains the given `text`, using the
[`textContent`][109]
attribute.

> Note: This assertion will collapse whitespace in `textContent` before searching.
> If you would like to assert on a string that _should_ contain line breaks, tabs,
> more than one space in a row, or starting/ending whitespace, use the [#hasText][110]
> selector and pass your expected text in as a RegEx pattern.

**Aliases:** `containsText`, `hasTextContaining`

#### Parameters

-   `text` **[string][91]** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('#title').includesText('Welcome');
```

### doesNotIncludeText

Assert that the text of the [HTMLElement][88] or an [HTMLElement][88]
matching the `selector` does not include the given `text`, using the
[`textContent`][109]
attribute.

**Aliases:** `doesNotContainText`, `doesNotHaveTextContaining`

#### Parameters

-   `text` **[string][91]** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('#title').doesNotIncludeText('Welcome');
```

### hasValue

-   **See: [#hasAnyValue][111]**
-   **See: [#hasNoValue][112]**

Assert that the `value` property of an [HTMLInputElement][113] matches
the `expected` text or regular expression.

If no `expected` value is provided, the assertion will fail if the
`value` is an empty string.

#### Parameters

-   `expected` **([string][91] \| [RegExp][101] \| [object][89]?)** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input.username').hasValue('HSimpson');
```

### hasAnyValue

-   **See: [#hasValue][114]**
-   **See: [#hasNoValue][112]**

Assert that the `value` property of an [HTMLInputElement][113] is not empty.

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input.username').hasAnyValue();
```

### hasNoValue

-   **See: [#hasValue][114]**
-   **See: [#hasAnyValue][111]**

Assert that the `value` property of an [HTMLInputElement][113] is empty.

**Aliases:** `lacksValue`

#### Parameters

-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input.username').hasNoValue();
```

### matchesSelector

Assert that the target selector selects only Elements that are also selected by
compareSelector.

#### Parameters

-   `compareSelector` **[string][91]** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('p.red').matchesSelector('div.wrapper p:last-child')
```

### doesNotMatchSelector

Assert that the target selector selects only Elements that are not also selected by
compareSelector.

#### Parameters

-   `compareSelector` **[string][91]** 
-   `message` **[string][91]?** 

#### Examples

```javascript
assert.dom('input').doesNotMatchSelector('input[disabled]')
```

## hasStyle

-   **See: [#hasClass][107]**

Assert that the [HTMLElement][] has the `expected` style declarations using
[`window.getComputedStyle`][115].

### Parameters

-   `expected` **[object][89]** 
-   `message` **[string][91]?** 

### Examples

```javascript
assert.dom('.progress-bar').hasStyle({
  opacity: 1,
  display: 'block'
});
```

## hasPseudoElementStyle

-   **See: [#hasClass][107]**

Assert that the pseudo element for `selector` of the [HTMLElement][] has the `expected` style declarations using
[`window.getComputedStyle`][115].

### Parameters

-   `selector` **[string][91]** 
-   `expected` **[object][89]** 
-   `message` **[string][91]?** 

### Examples

```javascript
assert.dom('.progress-bar').hasPseudoElementStyle(':after', {
  content: '";"',
});
```

[1]: #assertdom

[2]: #domassertions

[3]: #exists

[4]: #parameters

[5]: #examples

[6]: #doesnotexist

[7]: #parameters-1

[8]: #examples-1

[9]: #ischecked

[10]: #parameters-2

[11]: #examples-2

[12]: #isnotchecked

[13]: #parameters-3

[14]: #examples-3

[15]: #isfocused

[16]: #parameters-4

[17]: #examples-4

[18]: #isnotfocused

[19]: #parameters-5

[20]: #examples-5

[21]: #isrequired

[22]: #parameters-6

[23]: #examples-6

[24]: #isnotrequired

[25]: #parameters-7

[26]: #examples-7

[27]: #isvisible

[28]: #parameters-8

[29]: #examples-8

[30]: #isnotvisible

[31]: #parameters-9

[32]: #examples-9

[33]: #hasattribute

[34]: #parameters-10

[35]: #examples-10

[36]: #doesnothaveattribute

[37]: #parameters-11

[38]: #examples-11

[39]: #isdisabled

[40]: #parameters-12

[41]: #examples-12

[42]: #isnotdisabled

[43]: #parameters-13

[44]: #examples-13

[45]: #hasclass

[46]: #parameters-14

[47]: #examples-14

[48]: #doesnothaveclass

[49]: #parameters-15

[50]: #examples-15

[51]: #hastext

[52]: #parameters-16

[53]: #examples-16

[54]: #hasanytext

[55]: #parameters-17

[56]: #examples-17

[57]: #includestext

[58]: #parameters-18

[59]: #examples-18

[60]: #doesnotincludetext

[61]: #parameters-19

[62]: #examples-19

[63]: #hasvalue

[64]: #parameters-20

[65]: #examples-20

[66]: #hasanyvalue

[67]: #parameters-21

[68]: #examples-21

[69]: #hasnovalue

[70]: #parameters-22

[71]: #examples-22

[72]: #matchesselector

[73]: #parameters-23

[74]: #examples-23

[75]: #doesnotmatchselector

[76]: #parameters-24

[77]: #examples-24

[78]: #hasstyle

[79]: #parameters-25

[80]: #examples-25

[81]: #haspseudoelementstyle

[82]: #parameters-26

[83]: #examples-26

[84]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String

[85]: https://developer.mozilla.org/en-US/docs/Web/HTML/Element

[86]: https://developer.mozilla.org/de/docs/Web/API/Document/querySelector

[87]: #doesNotExist

[88]: https://developer.mozilla.org/docs/Web/HTML/Element

[89]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object

[90]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number

[91]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String

[92]: #isNotChecked

[93]: #isChecked

[94]: #isNotFocused

[95]: #isFocused

[96]: #isNotRequired

[97]: #isRequired

[98]: #isNotVisible

[99]: #isVisible

[100]: #doesNotHaveAttribute

[101]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/RegExp

[102]: #hasAttribute

[103]: #isNotDisabled

[104]: #isDisabled

[105]: #doesNotHaveClass

[106]: https://developer.mozilla.org/en-US/docs/Web/API/Element/classList

[107]: #hasClass

[108]: #includesText

[109]: https://developer.mozilla.org/en-US/docs/Web/API/Node/textContent

[110]: #hasText

[111]: #hasAnyValue

[112]: #hasNoValue

[113]: https://developer.mozilla.org/docs/Web/API/HTMLInputElement

[114]: #hasValue

[115]: https://developer.mozilla.org/en-US/docs/Web/API/Window/getComputedStyle
